#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog
version:              1.5
visibility:           public
id:                   hedgehog-1.5-LhImi99gXJSLmIknFHH4bW
key:                  hedgehog-1.5-LhImi99gXJSLmIknFHH4bW
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  384b2d5055d91e2847cdfaa858184241
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hedgehog-1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hedgehog-1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hedgehog-1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.5-LhImi99gXJSLmIknFHH4bW
depends:
    ansi-terminal-1.1-CI3Z2kdMs2nHILfQB59SyQ
    async-2.2.5-1xX3vMN4zg36fgeIvJ9Q4V
    barbies-2.1.1.0-BCpMnstrzukEL34h29LiaW base-4.18.2.1
    bytestring-0.11.5.3
    concurrent-output-1.10.21-BdFOT9Tqxt749R55JBQrz1 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5
    erf-2.0.0.0-4xz1P35HuR5Dy4ovZUgjCU exceptions-0.10.7
    lifted-async-0.11.0-44QwoMvvZ46GXYxrsBLeeP
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH
    monad-control-1.0.3.1-JuONgsuHNtm80swnBSZKdT mtl-2.3.1
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR
    primitive-0.9.1.0-DNYUiteSkWM3A4YLtDD08v
    random-1.2.1.3-8xCOAhjQqZaHKyZvNvQjlZ
    resourcet-1.2.6-DTR4j3s3u4b48dttywqklV
    safe-exceptions-0.1.7.4-Aukq1XqkIPGBTW2DUUo0Ri stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-INhQjWi7ZcS7vQVJ7Ssfgr
    wl-pprint-annotated-0.1.0.1-LfcMy6yYQBZ9U1hL6l67M5

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

